package com.microservices.zone.resource.service;

import com.microservices.common.core.web.page.GenericsTableDataInfo;
import com.microservices.system.api.domain.SysFileInfo;
import com.microservices.zone.resource.domain.ZoneResource;
import com.microservices.zone.resource.domain.vo.ZoneResourceAuditVo;
import com.microservices.zone.resource.domain.vo.ZoneResourceDataVo;
import com.microservices.zone.resource.domain.vo.ZoneResourceInputVo;
import com.microservices.zone.resource.domain.vo.ZoneResourceUpdateVo;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 特色专区资源聚合Service接口
 *
 * @author otto
 * @date 2023-06-27
 */
public interface IZoneResourceService {
    /**
     * 查询特色专区资源聚合
     *
     * @param id 特色专区资源聚合主键
     * @return 特色专区资源聚合
     */
    public ZoneResource selectZoneResourceById(Long id);

    /**
     * 查询特色专区资源聚合列表
     *
     * @param zoneResource 特色专区资源聚合
     * @return 特色专区资源聚合集合
     */
    public GenericsTableDataInfo<ZoneResourceDataVo> selectZoneResourceList(ZoneResource zoneResource);

    /**
     * 新增特色专区资源聚合
     *
     * @param zoneResourceInputVo 特色专区资源聚合
     * @return 结果
     */
    public ZoneResourceDataVo insertZoneResource(ZoneResourceInputVo zoneResourceInputVo);

    /**
     * 修改特色专区资源聚合
     *
     * @param zoneResourceUpdateVo 特色专区资源聚合
     * @return 结果
     */
    public ZoneResourceDataVo updateZoneResource(ZoneResourceUpdateVo zoneResourceUpdateVo);

    /**
     * 批量删除特色专区资源聚合
     *
     * @param ids 需要删除的特色专区资源聚合主键集合
     * @return 结果
     */
    public int deleteZoneResourceByIds(Long[] ids);

    /**
     * 删除特色专区资源聚合信息
     *
     * @param id 特色专区资源聚合主键
     * @return 结果
     */
    public int deleteZoneResourceById(Long id);

    /**
     * 获取资源数量
     *
     * @param zoneResource
     * @return
     */
    Integer selectZoneResourceCount(ZoneResource zoneResource);

    /**
     * 获取资源详情
     *
     * @param id
     * @return
     */
    ZoneResourceDataVo selectZoneResourceDataById(Long id);

    /**
     * 获取所有文件后缀（去重）
     *
     * @param fileIds
     * @return
     */
    public List<String> getAllFileSuffix(String fileIds);

    /**
     * 根据id列表获取文件列表
     *
     * @param fileIds
     * @return
     */
    List<SysFileInfo> getAllFileByFileIds(String fileIds);

    /**
     * 删除我的资源
     *
     * @param ids
     * @return
     */
    int deleteMyZoneResourceByIds(Long[] ids);

    /**
     * 审核专区资源
     *
     * @param zoneResourceAuditVo
     * @return
     */
    int auditZoneResource(ZoneResourceAuditVo zoneResourceAuditVo);

    /**
     * 公开接口查询资源详情
     *
     * @param resourceId
     * @param request
     * @return
     */
    ZoneResourceDataVo selectOpenZoneResourceDataById(Long resourceId, HttpServletRequest request);

    /**
     * 查询我的资源列表
     *
     * @param zoneResourceSearch
     * @return
     */
    GenericsTableDataInfo<ZoneResourceDataVo> selectMyZoneResourceList(ZoneResource zoneResourceSearch);

    /**
     * 查询我的资源列表总数
     *
     * @param zoneResourceSearch
     * @return
     */
    Integer selectMyZoneResourceCount(ZoneResource zoneResourceSearch);
}
